/****************************************************************************
** Meta object code from reading C++ file 'decorationbutton.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../kdecoration-5.27.12/src/decorationbutton.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'decorationbutton.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KDecoration2__DecorationButton_t {
    QByteArrayData data[31];
    char stringdata0[390];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KDecoration2__DecorationButton_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KDecoration2__DecorationButton_t qt_meta_stringdata_KDecoration2__DecorationButton = {
    {
QT_MOC_LITERAL(0, 0, 30), // "KDecoration2::DecorationButton"
QT_MOC_LITERAL(1, 31, 7), // "clicked"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 15), // "Qt::MouseButton"
QT_MOC_LITERAL(4, 56, 7), // "pressed"
QT_MOC_LITERAL(5, 64, 8), // "released"
QT_MOC_LITERAL(6, 73, 14), // "pointerEntered"
QT_MOC_LITERAL(7, 88, 11), // "pointerLeft"
QT_MOC_LITERAL(8, 100, 13), // "doubleClicked"
QT_MOC_LITERAL(9, 114, 14), // "pressedChanged"
QT_MOC_LITERAL(10, 129, 14), // "hoveredChanged"
QT_MOC_LITERAL(11, 144, 14), // "enabledChanged"
QT_MOC_LITERAL(12, 159, 16), // "checkableChanged"
QT_MOC_LITERAL(13, 176, 14), // "checkedChanged"
QT_MOC_LITERAL(14, 191, 15), // "geometryChanged"
QT_MOC_LITERAL(15, 207, 22), // "acceptedButtonsChanged"
QT_MOC_LITERAL(16, 230, 16), // "Qt::MouseButtons"
QT_MOC_LITERAL(17, 247, 17), // "visibilityChanged"
QT_MOC_LITERAL(18, 265, 10), // "setEnabled"
QT_MOC_LITERAL(19, 276, 7), // "enabled"
QT_MOC_LITERAL(20, 284, 12), // "setCheckable"
QT_MOC_LITERAL(21, 297, 9), // "checkable"
QT_MOC_LITERAL(22, 307, 10), // "setChecked"
QT_MOC_LITERAL(23, 318, 7), // "checked"
QT_MOC_LITERAL(24, 326, 10), // "setVisible"
QT_MOC_LITERAL(25, 337, 7), // "visible"
QT_MOC_LITERAL(26, 345, 6), // "update"
QT_MOC_LITERAL(27, 352, 4), // "rect"
QT_MOC_LITERAL(28, 357, 7), // "hovered"
QT_MOC_LITERAL(29, 365, 8), // "geometry"
QT_MOC_LITERAL(30, 374, 15) // "acceptedButtons"

    },
    "KDecoration2::DecorationButton\0clicked\0"
    "\0Qt::MouseButton\0pressed\0released\0"
    "pointerEntered\0pointerLeft\0doubleClicked\0"
    "pressedChanged\0hoveredChanged\0"
    "enabledChanged\0checkableChanged\0"
    "checkedChanged\0geometryChanged\0"
    "acceptedButtonsChanged\0Qt::MouseButtons\0"
    "visibilityChanged\0setEnabled\0enabled\0"
    "setCheckable\0checkable\0setChecked\0"
    "checked\0setVisible\0visible\0update\0"
    "rect\0hovered\0geometry\0acceptedButtons"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KDecoration2__DecorationButton[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      20,   14, // methods
       8,  162, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      14,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  114,    2, 0x06 /* Public */,
       4,    0,  117,    2, 0x06 /* Public */,
       5,    0,  118,    2, 0x06 /* Public */,
       6,    0,  119,    2, 0x06 /* Public */,
       7,    0,  120,    2, 0x06 /* Public */,
       8,    0,  121,    2, 0x06 /* Public */,
       9,    1,  122,    2, 0x06 /* Public */,
      10,    1,  125,    2, 0x06 /* Public */,
      11,    1,  128,    2, 0x06 /* Public */,
      12,    1,  131,    2, 0x06 /* Public */,
      13,    1,  134,    2, 0x06 /* Public */,
      14,    1,  137,    2, 0x06 /* Public */,
      15,    1,  140,    2, 0x06 /* Public */,
      17,    1,  143,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      18,    1,  146,    2, 0x0a /* Public */,
      20,    1,  149,    2, 0x0a /* Public */,
      22,    1,  152,    2, 0x0a /* Public */,
      24,    1,  155,    2, 0x0a /* Public */,
      26,    1,  158,    2, 0x0a /* Public */,
      26,    0,  161,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::QRectF,    2,
    QMetaType::Void, 0x80000000 | 16,    2,
    QMetaType::Void, QMetaType::Bool,    2,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,   19,
    QMetaType::Void, QMetaType::Bool,   21,
    QMetaType::Void, QMetaType::Bool,   23,
    QMetaType::Void, QMetaType::Bool,   25,
    QMetaType::Void, QMetaType::QRectF,   27,
    QMetaType::Void,

 // properties: name, type, flags
      25, QMetaType::Bool, 0x00495103,
       4, QMetaType::Bool, 0x00495001,
      28, QMetaType::Bool, 0x00495001,
      19, QMetaType::Bool, 0x00495103,
      21, QMetaType::Bool, 0x00495103,
      23, QMetaType::Bool, 0x00495103,
      29, QMetaType::QRectF, 0x00495001,
      30, 0x80000000 | 16, 0x0049510b,

 // properties: notify_signal_id
      13,
       6,
       7,
       8,
       9,
      10,
      11,
      12,

       0        // eod
};

void KDecoration2::DecorationButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DecorationButton *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->clicked((*reinterpret_cast< Qt::MouseButton(*)>(_a[1]))); break;
        case 1: _t->pressed(); break;
        case 2: _t->released(); break;
        case 3: _t->pointerEntered(); break;
        case 4: _t->pointerLeft(); break;
        case 5: _t->doubleClicked(); break;
        case 6: _t->pressedChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->hoveredChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->enabledChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->checkableChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->checkedChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 11: _t->geometryChanged((*reinterpret_cast< const QRectF(*)>(_a[1]))); break;
        case 12: _t->acceptedButtonsChanged((*reinterpret_cast< Qt::MouseButtons(*)>(_a[1]))); break;
        case 13: _t->visibilityChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 14: _t->setEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 15: _t->setCheckable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 16: _t->setChecked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 17: _t->setVisible((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 18: _t->update((*reinterpret_cast< const QRectF(*)>(_a[1]))); break;
        case 19: _t->update(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DecorationButton::*)(Qt::MouseButton );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecorationButton::clicked)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DecorationButton::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecorationButton::pressed)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DecorationButton::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecorationButton::released)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DecorationButton::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecorationButton::pointerEntered)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DecorationButton::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecorationButton::pointerLeft)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DecorationButton::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecorationButton::doubleClicked)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (DecorationButton::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecorationButton::pressedChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (DecorationButton::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecorationButton::hoveredChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (DecorationButton::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecorationButton::enabledChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (DecorationButton::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecorationButton::checkableChanged)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (DecorationButton::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecorationButton::checkedChanged)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (DecorationButton::*)(const QRectF & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecorationButton::geometryChanged)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (DecorationButton::*)(Qt::MouseButtons );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecorationButton::acceptedButtonsChanged)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (DecorationButton::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecorationButton::visibilityChanged)) {
                *result = 13;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DecorationButton *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->isVisible(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->isPressed(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->isHovered(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->isEnabled(); break;
        case 4: *reinterpret_cast< bool*>(_v) = _t->isCheckable(); break;
        case 5: *reinterpret_cast< bool*>(_v) = _t->isChecked(); break;
        case 6: *reinterpret_cast< QRectF*>(_v) = _t->geometry(); break;
        case 7: *reinterpret_cast< Qt::MouseButtons*>(_v) = _t->acceptedButtons(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DecorationButton *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setVisible(*reinterpret_cast< bool*>(_v)); break;
        case 3: _t->setEnabled(*reinterpret_cast< bool*>(_v)); break;
        case 4: _t->setCheckable(*reinterpret_cast< bool*>(_v)); break;
        case 5: _t->setChecked(*reinterpret_cast< bool*>(_v)); break;
        case 7: _t->setAcceptedButtons(*reinterpret_cast< Qt::MouseButtons*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject KDecoration2::DecorationButton::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_KDecoration2__DecorationButton.data,
    qt_meta_data_KDecoration2__DecorationButton,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KDecoration2::DecorationButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDecoration2::DecorationButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KDecoration2__DecorationButton.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KDecoration2::DecorationButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 20;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 8;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KDecoration2::DecorationButton::clicked(Qt::MouseButton _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KDecoration2::DecorationButton::pressed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KDecoration2::DecorationButton::released()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KDecoration2::DecorationButton::pointerEntered()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KDecoration2::DecorationButton::pointerLeft()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KDecoration2::DecorationButton::doubleClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KDecoration2::DecorationButton::pressedChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void KDecoration2::DecorationButton::hoveredChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void KDecoration2::DecorationButton::enabledChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void KDecoration2::DecorationButton::checkableChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void KDecoration2::DecorationButton::checkedChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void KDecoration2::DecorationButton::geometryChanged(const QRectF & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void KDecoration2::DecorationButton::acceptedButtonsChanged(Qt::MouseButtons _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void KDecoration2::DecorationButton::visibilityChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
