/****************************************************************************
** Meta object code from reading C++ file 'decorationsettings.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../kdecoration-5.27.12/src/decorationsettings.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QVector>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'decorationsettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KDecoration2__DecorationSettings_t {
    QByteArrayData data[25];
    char stringdata0[498];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KDecoration2__DecorationSettings_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KDecoration2__DecorationSettings_t qt_meta_stringdata_KDecoration2__DecorationSettings = {
    {
QT_MOC_LITERAL(0, 0, 32), // "KDecoration2::DecorationSettings"
QT_MOC_LITERAL(1, 33, 29), // "onAllDesktopsAvailableChanged"
QT_MOC_LITERAL(2, 63, 0), // ""
QT_MOC_LITERAL(3, 64, 28), // "alphaChannelSupportedChanged"
QT_MOC_LITERAL(4, 93, 31), // "closeOnDoubleClickOnMenuChanged"
QT_MOC_LITERAL(5, 125, 28), // "decorationButtonsLeftChanged"
QT_MOC_LITERAL(6, 154, 43), // "QVector<KDecoration2::Decorat..."
QT_MOC_LITERAL(7, 198, 29), // "decorationButtonsRightChanged"
QT_MOC_LITERAL(8, 228, 17), // "borderSizeChanged"
QT_MOC_LITERAL(9, 246, 24), // "KDecoration2::BorderSize"
QT_MOC_LITERAL(10, 271, 4), // "size"
QT_MOC_LITERAL(11, 276, 11), // "fontChanged"
QT_MOC_LITERAL(12, 288, 4), // "font"
QT_MOC_LITERAL(13, 293, 15), // "gridUnitChanged"
QT_MOC_LITERAL(14, 309, 14), // "spacingChanged"
QT_MOC_LITERAL(15, 324, 12), // "reconfigured"
QT_MOC_LITERAL(16, 337, 22), // "onAllDesktopsAvailable"
QT_MOC_LITERAL(17, 360, 21), // "alphaChannelSupported"
QT_MOC_LITERAL(18, 382, 24), // "closeOnDoubleClickOnMenu"
QT_MOC_LITERAL(19, 407, 21), // "decorationButtonsLeft"
QT_MOC_LITERAL(20, 429, 22), // "decorationButtonsRight"
QT_MOC_LITERAL(21, 452, 10), // "borderSize"
QT_MOC_LITERAL(22, 463, 8), // "gridUnit"
QT_MOC_LITERAL(23, 472, 12), // "smallSpacing"
QT_MOC_LITERAL(24, 485, 12) // "largeSpacing"

    },
    "KDecoration2::DecorationSettings\0"
    "onAllDesktopsAvailableChanged\0\0"
    "alphaChannelSupportedChanged\0"
    "closeOnDoubleClickOnMenuChanged\0"
    "decorationButtonsLeftChanged\0"
    "QVector<KDecoration2::DecorationButtonType>\0"
    "decorationButtonsRightChanged\0"
    "borderSizeChanged\0KDecoration2::BorderSize\0"
    "size\0fontChanged\0font\0gridUnitChanged\0"
    "spacingChanged\0reconfigured\0"
    "onAllDesktopsAvailable\0alphaChannelSupported\0"
    "closeOnDoubleClickOnMenu\0decorationButtonsLeft\0"
    "decorationButtonsRight\0borderSize\0"
    "gridUnit\0smallSpacing\0largeSpacing"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KDecoration2__DecorationSettings[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
      10,   90, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      10,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   64,    2, 0x06 /* Public */,
       3,    1,   67,    2, 0x06 /* Public */,
       4,    1,   70,    2, 0x06 /* Public */,
       5,    1,   73,    2, 0x06 /* Public */,
       7,    1,   76,    2, 0x06 /* Public */,
       8,    1,   79,    2, 0x06 /* Public */,
      11,    1,   82,    2, 0x06 /* Public */,
      13,    1,   85,    2, 0x06 /* Public */,
      14,    0,   88,    2, 0x06 /* Public */,
      15,    0,   89,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, QMetaType::QFont,   12,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
      16, QMetaType::Bool, 0x00495001,
      17, QMetaType::Bool, 0x00495001,
      18, QMetaType::Bool, 0x00495001,
      19, 0x80000000 | 6, 0x00495009,
      20, 0x80000000 | 6, 0x00495009,
      21, 0x80000000 | 9, 0x00495009,
      22, QMetaType::Int, 0x00495001,
      12, QMetaType::QFont, 0x00495001,
      23, QMetaType::Int, 0x00495001,
      24, QMetaType::Int, 0x00495001,

 // properties: notify_signal_id
       0,
       1,
       2,
       3,
       4,
       5,
       7,
       6,
       8,
       8,

       0        // eod
};

void KDecoration2::DecorationSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DecorationSettings *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->onAllDesktopsAvailableChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->alphaChannelSupportedChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->closeOnDoubleClickOnMenuChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->decorationButtonsLeftChanged((*reinterpret_cast< const QVector<KDecoration2::DecorationButtonType>(*)>(_a[1]))); break;
        case 4: _t->decorationButtonsRightChanged((*reinterpret_cast< const QVector<KDecoration2::DecorationButtonType>(*)>(_a[1]))); break;
        case 5: _t->borderSizeChanged((*reinterpret_cast< KDecoration2::BorderSize(*)>(_a[1]))); break;
        case 6: _t->fontChanged((*reinterpret_cast< const QFont(*)>(_a[1]))); break;
        case 7: _t->gridUnitChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->spacingChanged(); break;
        case 9: _t->reconfigured(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QVector<KDecoration2::DecorationButtonType> >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QVector<KDecoration2::DecorationButtonType> >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KDecoration2::BorderSize >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DecorationSettings::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecorationSettings::onAllDesktopsAvailableChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DecorationSettings::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecorationSettings::alphaChannelSupportedChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DecorationSettings::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecorationSettings::closeOnDoubleClickOnMenuChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DecorationSettings::*)(const QVector<KDecoration2::DecorationButtonType> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecorationSettings::decorationButtonsLeftChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DecorationSettings::*)(const QVector<KDecoration2::DecorationButtonType> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecorationSettings::decorationButtonsRightChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DecorationSettings::*)(KDecoration2::BorderSize );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecorationSettings::borderSizeChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (DecorationSettings::*)(const QFont & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecorationSettings::fontChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (DecorationSettings::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecorationSettings::gridUnitChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (DecorationSettings::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecorationSettings::spacingChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (DecorationSettings::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecorationSettings::reconfigured)) {
                *result = 9;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KDecoration2::BorderSize >(); break;
        case 4:
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QVector<KDecoration2::DecorationButtonType> >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DecorationSettings *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->isOnAllDesktopsAvailable(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->isAlphaChannelSupported(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->isCloseOnDoubleClickOnMenu(); break;
        case 3: *reinterpret_cast< QVector<KDecoration2::DecorationButtonType>*>(_v) = _t->decorationButtonsLeft(); break;
        case 4: *reinterpret_cast< QVector<KDecoration2::DecorationButtonType>*>(_v) = _t->decorationButtonsRight(); break;
        case 5: *reinterpret_cast< KDecoration2::BorderSize*>(_v) = _t->borderSize(); break;
        case 6: *reinterpret_cast< int*>(_v) = _t->gridUnit(); break;
        case 7: *reinterpret_cast< QFont*>(_v) = _t->font(); break;
        case 8: *reinterpret_cast< int*>(_v) = _t->smallSpacing(); break;
        case 9: *reinterpret_cast< int*>(_v) = _t->largeSpacing(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject KDecoration2::DecorationSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_KDecoration2__DecorationSettings.data,
    qt_meta_data_KDecoration2__DecorationSettings,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KDecoration2::DecorationSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDecoration2::DecorationSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KDecoration2__DecorationSettings.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KDecoration2::DecorationSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 10;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KDecoration2::DecorationSettings::onAllDesktopsAvailableChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KDecoration2::DecorationSettings::alphaChannelSupportedChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KDecoration2::DecorationSettings::closeOnDoubleClickOnMenuChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KDecoration2::DecorationSettings::decorationButtonsLeftChanged(const QVector<KDecoration2::DecorationButtonType> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KDecoration2::DecorationSettings::decorationButtonsRightChanged(const QVector<KDecoration2::DecorationButtonType> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void KDecoration2::DecorationSettings::borderSizeChanged(KDecoration2::BorderSize _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void KDecoration2::DecorationSettings::fontChanged(const QFont & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void KDecoration2::DecorationSettings::gridUnitChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void KDecoration2::DecorationSettings::spacingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void KDecoration2::DecorationSettings::reconfigured()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
