/****************************************************************************
** Meta object code from reading C++ file 'decoratedclient.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../kdecoration-5.27.12/src/decoratedclient.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'decoratedclient.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KDecoration2__DecoratedClient_t {
    QByteArrayData data[57];
    char stringdata0[853];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KDecoration2__DecoratedClient_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KDecoration2__DecoratedClient_t qt_meta_stringdata_KDecoration2__DecoratedClient = {
    {
QT_MOC_LITERAL(0, 0, 29), // "KDecoration2::DecoratedClient"
QT_MOC_LITERAL(1, 30, 13), // "activeChanged"
QT_MOC_LITERAL(2, 44, 0), // ""
QT_MOC_LITERAL(3, 45, 14), // "captionChanged"
QT_MOC_LITERAL(4, 60, 14), // "desktopChanged"
QT_MOC_LITERAL(5, 75, 20), // "onAllDesktopsChanged"
QT_MOC_LITERAL(6, 96, 13), // "shadedChanged"
QT_MOC_LITERAL(7, 110, 11), // "iconChanged"
QT_MOC_LITERAL(8, 122, 16), // "maximizedChanged"
QT_MOC_LITERAL(9, 139, 28), // "maximizedHorizontallyChanged"
QT_MOC_LITERAL(10, 168, 26), // "maximizedVerticallyChanged"
QT_MOC_LITERAL(11, 195, 16), // "keepAboveChanged"
QT_MOC_LITERAL(12, 212, 16), // "keepBelowChanged"
QT_MOC_LITERAL(13, 229, 16), // "closeableChanged"
QT_MOC_LITERAL(14, 246, 19), // "maximizeableChanged"
QT_MOC_LITERAL(15, 266, 19), // "minimizeableChanged"
QT_MOC_LITERAL(16, 286, 26), // "providesContextHelpChanged"
QT_MOC_LITERAL(17, 313, 16), // "shadeableChanged"
QT_MOC_LITERAL(18, 330, 15), // "moveableChanged"
QT_MOC_LITERAL(19, 346, 17), // "resizeableChanged"
QT_MOC_LITERAL(20, 364, 12), // "widthChanged"
QT_MOC_LITERAL(21, 377, 13), // "heightChanged"
QT_MOC_LITERAL(22, 391, 11), // "sizeChanged"
QT_MOC_LITERAL(23, 403, 4), // "size"
QT_MOC_LITERAL(24, 408, 14), // "paletteChanged"
QT_MOC_LITERAL(25, 423, 7), // "palette"
QT_MOC_LITERAL(26, 431, 26), // "adjacentScreenEdgesChanged"
QT_MOC_LITERAL(27, 458, 9), // "Qt::Edges"
QT_MOC_LITERAL(28, 468, 5), // "edges"
QT_MOC_LITERAL(29, 474, 25), // "hasApplicationMenuChanged"
QT_MOC_LITERAL(30, 500, 28), // "applicationMenuActiveChanged"
QT_MOC_LITERAL(31, 529, 10), // "decoration"
QT_MOC_LITERAL(32, 540, 25), // "KDecoration2::Decoration*"
QT_MOC_LITERAL(33, 566, 6), // "active"
QT_MOC_LITERAL(34, 573, 7), // "caption"
QT_MOC_LITERAL(35, 581, 7), // "desktop"
QT_MOC_LITERAL(36, 589, 13), // "onAllDesktops"
QT_MOC_LITERAL(37, 603, 6), // "shaded"
QT_MOC_LITERAL(38, 610, 4), // "icon"
QT_MOC_LITERAL(39, 615, 9), // "maximized"
QT_MOC_LITERAL(40, 625, 21), // "maximizedHorizontally"
QT_MOC_LITERAL(41, 647, 19), // "maximizedVertically"
QT_MOC_LITERAL(42, 667, 9), // "keepAbove"
QT_MOC_LITERAL(43, 677, 9), // "keepBelow"
QT_MOC_LITERAL(44, 687, 9), // "closeable"
QT_MOC_LITERAL(45, 697, 12), // "maximizeable"
QT_MOC_LITERAL(46, 710, 12), // "minimizeable"
QT_MOC_LITERAL(47, 723, 19), // "providesContextHelp"
QT_MOC_LITERAL(48, 743, 5), // "modal"
QT_MOC_LITERAL(49, 749, 9), // "shadeable"
QT_MOC_LITERAL(50, 759, 8), // "moveable"
QT_MOC_LITERAL(51, 768, 10), // "resizeable"
QT_MOC_LITERAL(52, 779, 5), // "width"
QT_MOC_LITERAL(53, 785, 6), // "height"
QT_MOC_LITERAL(54, 792, 19), // "adjacentScreenEdges"
QT_MOC_LITERAL(55, 812, 18), // "hasApplicationMenu"
QT_MOC_LITERAL(56, 831, 21) // "applicationMenuActive"

    },
    "KDecoration2::DecoratedClient\0"
    "activeChanged\0\0captionChanged\0"
    "desktopChanged\0onAllDesktopsChanged\0"
    "shadedChanged\0iconChanged\0maximizedChanged\0"
    "maximizedHorizontallyChanged\0"
    "maximizedVerticallyChanged\0keepAboveChanged\0"
    "keepBelowChanged\0closeableChanged\0"
    "maximizeableChanged\0minimizeableChanged\0"
    "providesContextHelpChanged\0shadeableChanged\0"
    "moveableChanged\0resizeableChanged\0"
    "widthChanged\0heightChanged\0sizeChanged\0"
    "size\0paletteChanged\0palette\0"
    "adjacentScreenEdgesChanged\0Qt::Edges\0"
    "edges\0hasApplicationMenuChanged\0"
    "applicationMenuActiveChanged\0decoration\0"
    "KDecoration2::Decoration*\0active\0"
    "caption\0desktop\0onAllDesktops\0shaded\0"
    "icon\0maximized\0maximizedHorizontally\0"
    "maximizedVertically\0keepAbove\0keepBelow\0"
    "closeable\0maximizeable\0minimizeable\0"
    "providesContextHelp\0modal\0shadeable\0"
    "moveable\0resizeable\0width\0height\0"
    "adjacentScreenEdges\0hasApplicationMenu\0"
    "applicationMenuActive"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KDecoration2__DecoratedClient[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      25,   14, // methods
      27,  214, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      25,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  139,    2, 0x06 /* Public */,
       3,    1,  142,    2, 0x06 /* Public */,
       4,    1,  145,    2, 0x06 /* Public */,
       5,    1,  148,    2, 0x06 /* Public */,
       6,    1,  151,    2, 0x06 /* Public */,
       7,    1,  154,    2, 0x06 /* Public */,
       8,    1,  157,    2, 0x06 /* Public */,
       9,    1,  160,    2, 0x06 /* Public */,
      10,    1,  163,    2, 0x06 /* Public */,
      11,    1,  166,    2, 0x06 /* Public */,
      12,    1,  169,    2, 0x06 /* Public */,
      13,    1,  172,    2, 0x06 /* Public */,
      14,    1,  175,    2, 0x06 /* Public */,
      15,    1,  178,    2, 0x06 /* Public */,
      16,    1,  181,    2, 0x06 /* Public */,
      17,    1,  184,    2, 0x06 /* Public */,
      18,    1,  187,    2, 0x06 /* Public */,
      19,    1,  190,    2, 0x06 /* Public */,
      20,    1,  193,    2, 0x06 /* Public */,
      21,    1,  196,    2, 0x06 /* Public */,
      22,    1,  199,    2, 0x06 /* Public */,
      24,    1,  202,    2, 0x06 /* Public */,
      26,    1,  205,    2, 0x06 /* Public */,
      29,    1,  208,    2, 0x06 /* Public */,
      30,    1,  211,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::QIcon,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::QSize,   23,
    QMetaType::Void, QMetaType::QPalette,   25,
    QMetaType::Void, 0x80000000 | 27,   28,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,

 // properties: name, type, flags
      31, 0x80000000 | 32, 0x00095409,
      33, QMetaType::Bool, 0x00495001,
      34, QMetaType::QString, 0x00495001,
      35, QMetaType::Int, 0x00495001,
      36, QMetaType::Bool, 0x00495001,
      37, QMetaType::Bool, 0x00495001,
      38, QMetaType::QIcon, 0x00495001,
      39, QMetaType::Bool, 0x00495001,
      40, QMetaType::Bool, 0x00495001,
      41, QMetaType::Bool, 0x00495001,
      42, QMetaType::Bool, 0x00495001,
      43, QMetaType::Bool, 0x00495001,
      44, QMetaType::Bool, 0x00495001,
      45, QMetaType::Bool, 0x00495001,
      46, QMetaType::Bool, 0x00495001,
      47, QMetaType::Bool, 0x00495001,
      48, QMetaType::Bool, 0x00095401,
      49, QMetaType::Bool, 0x00495001,
      50, QMetaType::Bool, 0x00495001,
      51, QMetaType::Bool, 0x00495001,
      52, QMetaType::Int, 0x00495001,
      53, QMetaType::Int, 0x00495001,
      23, QMetaType::QSize, 0x00495001,
      25, QMetaType::QPalette, 0x00495001,
      54, 0x80000000 | 27, 0x00495009,
      55, QMetaType::Bool, 0x00495001,
      56, QMetaType::Bool, 0x00495001,

 // properties: notify_signal_id
       0,
       0,
       1,
       2,
       3,
       4,
       5,
       6,
       7,
       8,
       9,
      10,
      11,
      12,
      13,
      14,
       0,
      15,
      16,
      17,
      18,
      19,
      20,
      21,
      22,
      23,
      24,

       0        // eod
};

void KDecoration2::DecoratedClient::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DecoratedClient *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->activeChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->captionChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 2: _t->desktopChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->onAllDesktopsChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->shadedChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->iconChanged((*reinterpret_cast< QIcon(*)>(_a[1]))); break;
        case 6: _t->maximizedChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->maximizedHorizontallyChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->maximizedVerticallyChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->keepAboveChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->keepBelowChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 11: _t->closeableChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 12: _t->maximizeableChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 13: _t->minimizeableChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 14: _t->providesContextHelpChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 15: _t->shadeableChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 16: _t->moveableChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 17: _t->resizeableChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 18: _t->widthChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 19: _t->heightChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 20: _t->sizeChanged((*reinterpret_cast< const QSize(*)>(_a[1]))); break;
        case 21: _t->paletteChanged((*reinterpret_cast< const QPalette(*)>(_a[1]))); break;
        case 22: _t->adjacentScreenEdgesChanged((*reinterpret_cast< Qt::Edges(*)>(_a[1]))); break;
        case 23: _t->hasApplicationMenuChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 24: _t->applicationMenuActiveChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DecoratedClient::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecoratedClient::activeChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DecoratedClient::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecoratedClient::captionChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DecoratedClient::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecoratedClient::desktopChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DecoratedClient::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecoratedClient::onAllDesktopsChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DecoratedClient::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecoratedClient::shadedChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DecoratedClient::*)(QIcon );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecoratedClient::iconChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (DecoratedClient::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecoratedClient::maximizedChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (DecoratedClient::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecoratedClient::maximizedHorizontallyChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (DecoratedClient::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecoratedClient::maximizedVerticallyChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (DecoratedClient::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecoratedClient::keepAboveChanged)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (DecoratedClient::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecoratedClient::keepBelowChanged)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (DecoratedClient::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecoratedClient::closeableChanged)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (DecoratedClient::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecoratedClient::maximizeableChanged)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (DecoratedClient::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecoratedClient::minimizeableChanged)) {
                *result = 13;
                return;
            }
        }
        {
            using _t = void (DecoratedClient::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecoratedClient::providesContextHelpChanged)) {
                *result = 14;
                return;
            }
        }
        {
            using _t = void (DecoratedClient::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecoratedClient::shadeableChanged)) {
                *result = 15;
                return;
            }
        }
        {
            using _t = void (DecoratedClient::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecoratedClient::moveableChanged)) {
                *result = 16;
                return;
            }
        }
        {
            using _t = void (DecoratedClient::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecoratedClient::resizeableChanged)) {
                *result = 17;
                return;
            }
        }
        {
            using _t = void (DecoratedClient::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecoratedClient::widthChanged)) {
                *result = 18;
                return;
            }
        }
        {
            using _t = void (DecoratedClient::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecoratedClient::heightChanged)) {
                *result = 19;
                return;
            }
        }
        {
            using _t = void (DecoratedClient::*)(const QSize & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecoratedClient::sizeChanged)) {
                *result = 20;
                return;
            }
        }
        {
            using _t = void (DecoratedClient::*)(const QPalette & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecoratedClient::paletteChanged)) {
                *result = 21;
                return;
            }
        }
        {
            using _t = void (DecoratedClient::*)(Qt::Edges );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecoratedClient::adjacentScreenEdgesChanged)) {
                *result = 22;
                return;
            }
        }
        {
            using _t = void (DecoratedClient::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecoratedClient::hasApplicationMenuChanged)) {
                *result = 23;
                return;
            }
        }
        {
            using _t = void (DecoratedClient::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecoratedClient::applicationMenuActiveChanged)) {
                *result = 24;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KDecoration2::Decoration* >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DecoratedClient *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< KDecoration2::Decoration**>(_v) = _t->decoration(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->isActive(); break;
        case 2: *reinterpret_cast< QString*>(_v) = _t->caption(); break;
        case 3: *reinterpret_cast< int*>(_v) = _t->desktop(); break;
        case 4: *reinterpret_cast< bool*>(_v) = _t->isOnAllDesktops(); break;
        case 5: *reinterpret_cast< bool*>(_v) = _t->isShaded(); break;
        case 6: *reinterpret_cast< QIcon*>(_v) = _t->icon(); break;
        case 7: *reinterpret_cast< bool*>(_v) = _t->isMaximized(); break;
        case 8: *reinterpret_cast< bool*>(_v) = _t->isMaximizedHorizontally(); break;
        case 9: *reinterpret_cast< bool*>(_v) = _t->isMaximizedVertically(); break;
        case 10: *reinterpret_cast< bool*>(_v) = _t->isKeepAbove(); break;
        case 11: *reinterpret_cast< bool*>(_v) = _t->isKeepBelow(); break;
        case 12: *reinterpret_cast< bool*>(_v) = _t->isCloseable(); break;
        case 13: *reinterpret_cast< bool*>(_v) = _t->isMaximizeable(); break;
        case 14: *reinterpret_cast< bool*>(_v) = _t->isMinimizeable(); break;
        case 15: *reinterpret_cast< bool*>(_v) = _t->providesContextHelp(); break;
        case 16: *reinterpret_cast< bool*>(_v) = _t->isModal(); break;
        case 17: *reinterpret_cast< bool*>(_v) = _t->isShadeable(); break;
        case 18: *reinterpret_cast< bool*>(_v) = _t->isMoveable(); break;
        case 19: *reinterpret_cast< bool*>(_v) = _t->isResizeable(); break;
        case 20: *reinterpret_cast< int*>(_v) = _t->width(); break;
        case 21: *reinterpret_cast< int*>(_v) = _t->height(); break;
        case 22: *reinterpret_cast< QSize*>(_v) = _t->size(); break;
        case 23: *reinterpret_cast< QPalette*>(_v) = _t->palette(); break;
        case 24: *reinterpret_cast< Qt::Edges*>(_v) = _t->adjacentScreenEdges(); break;
        case 25: *reinterpret_cast< bool*>(_v) = _t->hasApplicationMenu(); break;
        case 26: *reinterpret_cast< bool*>(_v) = _t->isApplicationMenuActive(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject KDecoration2::DecoratedClient::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_KDecoration2__DecoratedClient.data,
    qt_meta_data_KDecoration2__DecoratedClient,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KDecoration2::DecoratedClient::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDecoration2::DecoratedClient::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KDecoration2__DecoratedClient.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KDecoration2::DecoratedClient::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 25;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 27;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 27;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 27;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 27;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 27;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KDecoration2::DecoratedClient::activeChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KDecoration2::DecoratedClient::captionChanged(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KDecoration2::DecoratedClient::desktopChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KDecoration2::DecoratedClient::onAllDesktopsChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KDecoration2::DecoratedClient::shadedChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void KDecoration2::DecoratedClient::iconChanged(QIcon _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void KDecoration2::DecoratedClient::maximizedChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void KDecoration2::DecoratedClient::maximizedHorizontallyChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void KDecoration2::DecoratedClient::maximizedVerticallyChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void KDecoration2::DecoratedClient::keepAboveChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void KDecoration2::DecoratedClient::keepBelowChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void KDecoration2::DecoratedClient::closeableChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void KDecoration2::DecoratedClient::maximizeableChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void KDecoration2::DecoratedClient::minimizeableChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void KDecoration2::DecoratedClient::providesContextHelpChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void KDecoration2::DecoratedClient::shadeableChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 16
void KDecoration2::DecoratedClient::moveableChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 16, _a);
}

// SIGNAL 17
void KDecoration2::DecoratedClient::resizeableChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 17, _a);
}

// SIGNAL 18
void KDecoration2::DecoratedClient::widthChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 18, _a);
}

// SIGNAL 19
void KDecoration2::DecoratedClient::heightChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 19, _a);
}

// SIGNAL 20
void KDecoration2::DecoratedClient::sizeChanged(const QSize & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 20, _a);
}

// SIGNAL 21
void KDecoration2::DecoratedClient::paletteChanged(const QPalette & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 21, _a);
}

// SIGNAL 22
void KDecoration2::DecoratedClient::adjacentScreenEdgesChanged(Qt::Edges _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 22, _a);
}

// SIGNAL 23
void KDecoration2::DecoratedClient::hasApplicationMenuChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 23, _a);
}

// SIGNAL 24
void KDecoration2::DecoratedClient::applicationMenuActiveChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 24, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
