/****************************************************************************
** Meta object code from reading C++ file 'decorationshadow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../kdecoration-5.27.12/src/decorationshadow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'decorationshadow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KDecoration2__DecorationShadow_t {
    QByteArrayData data[21];
    char stringdata0[300];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KDecoration2__DecorationShadow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KDecoration2__DecorationShadow_t qt_meta_stringdata_KDecoration2__DecorationShadow = {
    {
QT_MOC_LITERAL(0, 0, 30), // "KDecoration2::DecorationShadow"
QT_MOC_LITERAL(1, 31, 13), // "shadowChanged"
QT_MOC_LITERAL(2, 45, 0), // ""
QT_MOC_LITERAL(3, 46, 22), // "innerShadowRectChanged"
QT_MOC_LITERAL(4, 69, 14), // "paddingChanged"
QT_MOC_LITERAL(5, 84, 6), // "shadow"
QT_MOC_LITERAL(6, 91, 15), // "innerShadowRect"
QT_MOC_LITERAL(7, 107, 15), // "topLeftGeometry"
QT_MOC_LITERAL(8, 123, 11), // "topGeometry"
QT_MOC_LITERAL(9, 135, 16), // "topRightGeometry"
QT_MOC_LITERAL(10, 152, 13), // "rightGeometry"
QT_MOC_LITERAL(11, 166, 19), // "bottomRightGeometry"
QT_MOC_LITERAL(12, 186, 14), // "bottomGeometry"
QT_MOC_LITERAL(13, 201, 18), // "bottomLeftGeometry"
QT_MOC_LITERAL(14, 220, 12), // "leftGeometry"
QT_MOC_LITERAL(15, 233, 10), // "paddingTop"
QT_MOC_LITERAL(16, 244, 12), // "paddingRight"
QT_MOC_LITERAL(17, 257, 13), // "paddingBottom"
QT_MOC_LITERAL(18, 271, 11), // "paddingLeft"
QT_MOC_LITERAL(19, 283, 7), // "padding"
QT_MOC_LITERAL(20, 291, 8) // "QMargins"

    },
    "KDecoration2::DecorationShadow\0"
    "shadowChanged\0\0innerShadowRectChanged\0"
    "paddingChanged\0shadow\0innerShadowRect\0"
    "topLeftGeometry\0topGeometry\0"
    "topRightGeometry\0rightGeometry\0"
    "bottomRightGeometry\0bottomGeometry\0"
    "bottomLeftGeometry\0leftGeometry\0"
    "paddingTop\0paddingRight\0paddingBottom\0"
    "paddingLeft\0padding\0QMargins"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KDecoration2__DecorationShadow[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
      15,   34, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   29,    2, 0x06 /* Public */,
       3,    0,   32,    2, 0x06 /* Public */,
       4,    0,   33,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QImage,    2,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
       5, QMetaType::QImage, 0x00495103,
       6, QMetaType::QRect, 0x00495103,
       7, QMetaType::QRect, 0x00495001,
       8, QMetaType::QRect, 0x00495001,
       9, QMetaType::QRect, 0x00495001,
      10, QMetaType::QRect, 0x00495001,
      11, QMetaType::QRect, 0x00495001,
      12, QMetaType::QRect, 0x00495001,
      13, QMetaType::QRect, 0x00495001,
      14, QMetaType::QRect, 0x00495001,
      15, QMetaType::Int, 0x00495001,
      16, QMetaType::Int, 0x00495001,
      17, QMetaType::Int, 0x00495001,
      18, QMetaType::Int, 0x00495001,
      19, 0x80000000 | 20, 0x0049510b,

 // properties: notify_signal_id
       0,
       1,
       1,
       1,
       1,
       1,
       1,
       1,
       1,
       1,
       2,
       2,
       2,
       2,
       2,

       0        // eod
};

void KDecoration2::DecorationShadow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DecorationShadow *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->shadowChanged((*reinterpret_cast< const QImage(*)>(_a[1]))); break;
        case 1: _t->innerShadowRectChanged(); break;
        case 2: _t->paddingChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DecorationShadow::*)(const QImage & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecorationShadow::shadowChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DecorationShadow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecorationShadow::innerShadowRectChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DecorationShadow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DecorationShadow::paddingChanged)) {
                *result = 2;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DecorationShadow *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QImage*>(_v) = _t->shadow(); break;
        case 1: *reinterpret_cast< QRect*>(_v) = _t->innerShadowRect(); break;
        case 2: *reinterpret_cast< QRect*>(_v) = _t->topLeftGeometry(); break;
        case 3: *reinterpret_cast< QRect*>(_v) = _t->topGeometry(); break;
        case 4: *reinterpret_cast< QRect*>(_v) = _t->topRightGeometry(); break;
        case 5: *reinterpret_cast< QRect*>(_v) = _t->rightGeometry(); break;
        case 6: *reinterpret_cast< QRect*>(_v) = _t->bottomRightGeometry(); break;
        case 7: *reinterpret_cast< QRect*>(_v) = _t->bottomGeometry(); break;
        case 8: *reinterpret_cast< QRect*>(_v) = _t->bottomLeftGeometry(); break;
        case 9: *reinterpret_cast< QRect*>(_v) = _t->leftGeometry(); break;
        case 10: *reinterpret_cast< int*>(_v) = _t->paddingTop(); break;
        case 11: *reinterpret_cast< int*>(_v) = _t->paddingRight(); break;
        case 12: *reinterpret_cast< int*>(_v) = _t->paddingBottom(); break;
        case 13: *reinterpret_cast< int*>(_v) = _t->paddingLeft(); break;
        case 14: *reinterpret_cast< QMargins*>(_v) = _t->padding(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DecorationShadow *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setShadow(*reinterpret_cast< QImage*>(_v)); break;
        case 1: _t->setInnerShadowRect(*reinterpret_cast< QRect*>(_v)); break;
        case 14: _t->setPadding(*reinterpret_cast< QMargins*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject KDecoration2::DecorationShadow::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_KDecoration2__DecorationShadow.data,
    qt_meta_data_KDecoration2__DecorationShadow,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KDecoration2::DecorationShadow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDecoration2::DecorationShadow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KDecoration2__DecorationShadow.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KDecoration2::DecorationShadow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 15;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 15;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 15;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 15;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 15;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KDecoration2::DecorationShadow::shadowChanged(const QImage & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KDecoration2::DecorationShadow::innerShadowRectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KDecoration2::DecorationShadow::paddingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
