/****************************************************************************
** Meta object code from reading C++ file 'decoration.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../kdecoration-5.27.12/src/decoration.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QSharedPointer>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'decoration.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KDecoration2__Decoration_t {
    QByteArrayData data[48];
    char stringdata0[761];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KDecoration2__Decoration_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KDecoration2__Decoration_t qt_meta_stringdata_KDecoration2__Decoration = {
    {
QT_MOC_LITERAL(0, 0, 24), // "KDecoration2::Decoration"
QT_MOC_LITERAL(1, 25, 17), // "blurRegionChanged"
QT_MOC_LITERAL(2, 43, 0), // ""
QT_MOC_LITERAL(3, 44, 14), // "bordersChanged"
QT_MOC_LITERAL(4, 59, 24), // "resizeOnlyBordersChanged"
QT_MOC_LITERAL(5, 84, 24), // "sectionUnderMouseChanged"
QT_MOC_LITERAL(6, 109, 22), // "Qt::WindowFrameSection"
QT_MOC_LITERAL(7, 132, 15), // "titleBarChanged"
QT_MOC_LITERAL(8, 148, 13), // "opaqueChanged"
QT_MOC_LITERAL(9, 162, 13), // "shadowChanged"
QT_MOC_LITERAL(10, 176, 32), // "QSharedPointer<DecorationShadow>"
QT_MOC_LITERAL(11, 209, 6), // "shadow"
QT_MOC_LITERAL(12, 216, 7), // "damaged"
QT_MOC_LITERAL(13, 224, 6), // "region"
QT_MOC_LITERAL(14, 231, 12), // "requestClose"
QT_MOC_LITERAL(15, 244, 25), // "requestToggleMaximization"
QT_MOC_LITERAL(16, 270, 16), // "Qt::MouseButtons"
QT_MOC_LITERAL(17, 287, 7), // "buttons"
QT_MOC_LITERAL(18, 295, 15), // "requestMinimize"
QT_MOC_LITERAL(19, 311, 18), // "requestContextHelp"
QT_MOC_LITERAL(20, 330, 26), // "requestToggleOnAllDesktops"
QT_MOC_LITERAL(21, 357, 18), // "requestToggleShade"
QT_MOC_LITERAL(22, 376, 22), // "requestToggleKeepAbove"
QT_MOC_LITERAL(23, 399, 22), // "requestToggleKeepBelow"
QT_MOC_LITERAL(24, 422, 21), // "requestShowWindowMenu"
QT_MOC_LITERAL(25, 444, 4), // "rect"
QT_MOC_LITERAL(26, 449, 18), // "requestShowToolTip"
QT_MOC_LITERAL(27, 468, 4), // "text"
QT_MOC_LITERAL(28, 473, 18), // "requestHideToolTip"
QT_MOC_LITERAL(29, 492, 19), // "showApplicationMenu"
QT_MOC_LITERAL(30, 512, 8), // "actionId"
QT_MOC_LITERAL(31, 521, 26), // "requestShowApplicationMenu"
QT_MOC_LITERAL(32, 548, 6), // "update"
QT_MOC_LITERAL(33, 555, 4), // "init"
QT_MOC_LITERAL(34, 560, 7), // "borders"
QT_MOC_LITERAL(35, 568, 8), // "QMargins"
QT_MOC_LITERAL(36, 577, 10), // "borderLeft"
QT_MOC_LITERAL(37, 588, 11), // "borderRight"
QT_MOC_LITERAL(38, 600, 9), // "borderTop"
QT_MOC_LITERAL(39, 610, 12), // "borderBottom"
QT_MOC_LITERAL(40, 623, 17), // "resizeOnlyBorders"
QT_MOC_LITERAL(41, 641, 20), // "resizeOnlyBorderLeft"
QT_MOC_LITERAL(42, 662, 21), // "resizeOnlyBorderRight"
QT_MOC_LITERAL(43, 684, 19), // "resizeOnlyBorderTop"
QT_MOC_LITERAL(44, 704, 22), // "resizeOnlyBorderBottom"
QT_MOC_LITERAL(45, 727, 17), // "sectionUnderMouse"
QT_MOC_LITERAL(46, 745, 8), // "titleBar"
QT_MOC_LITERAL(47, 754, 6) // "opaque"

    },
    "KDecoration2::Decoration\0blurRegionChanged\0"
    "\0bordersChanged\0resizeOnlyBordersChanged\0"
    "sectionUnderMouseChanged\0"
    "Qt::WindowFrameSection\0titleBarChanged\0"
    "opaqueChanged\0shadowChanged\0"
    "QSharedPointer<DecorationShadow>\0"
    "shadow\0damaged\0region\0requestClose\0"
    "requestToggleMaximization\0Qt::MouseButtons\0"
    "buttons\0requestMinimize\0requestContextHelp\0"
    "requestToggleOnAllDesktops\0"
    "requestToggleShade\0requestToggleKeepAbove\0"
    "requestToggleKeepBelow\0requestShowWindowMenu\0"
    "rect\0requestShowToolTip\0text\0"
    "requestHideToolTip\0showApplicationMenu\0"
    "actionId\0requestShowApplicationMenu\0"
    "update\0init\0borders\0QMargins\0borderLeft\0"
    "borderRight\0borderTop\0borderBottom\0"
    "resizeOnlyBorders\0resizeOnlyBorderLeft\0"
    "resizeOnlyBorderRight\0resizeOnlyBorderTop\0"
    "resizeOnlyBorderBottom\0sectionUnderMouse\0"
    "titleBar\0opaque"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KDecoration2__Decoration[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      25,   14, // methods
      13,  186, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       8,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  139,    2, 0x06 /* Public */,
       3,    0,  140,    2, 0x06 /* Public */,
       4,    0,  141,    2, 0x06 /* Public */,
       5,    1,  142,    2, 0x06 /* Public */,
       7,    0,  145,    2, 0x06 /* Public */,
       8,    1,  146,    2, 0x06 /* Public */,
       9,    1,  149,    2, 0x06 /* Public */,
      12,    1,  152,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      14,    0,  155,    2, 0x0a /* Public */,
      15,    1,  156,    2, 0x0a /* Public */,
      18,    0,  159,    2, 0x0a /* Public */,
      19,    0,  160,    2, 0x0a /* Public */,
      20,    0,  161,    2, 0x0a /* Public */,
      21,    0,  162,    2, 0x0a /* Public */,
      22,    0,  163,    2, 0x0a /* Public */,
      23,    0,  164,    2, 0x0a /* Public */,
      24,    0,  165,    2, 0x0a /* Public */,
      24,    1,  166,    2, 0x0a /* Public */,
      26,    1,  169,    2, 0x0a /* Public */,
      28,    0,  172,    2, 0x0a /* Public */,
      29,    1,  173,    2, 0x0a /* Public */,
      31,    2,  176,    2, 0x0a /* Public */,
      32,    1,  181,    2, 0x0a /* Public */,
      32,    0,  184,    2, 0x0a /* Public */,
      33,    0,  185,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void, QMetaType::QRegion,   13,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 16,   17,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QRect,   25,
    QMetaType::Void, QMetaType::QString,   27,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   30,
    QMetaType::Void, QMetaType::QRect, QMetaType::Int,   25,   30,
    QMetaType::Void, QMetaType::QRect,   25,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
      34, 0x80000000 | 35, 0x00495009,
      36, QMetaType::Int, 0x00495001,
      37, QMetaType::Int, 0x00495001,
      38, QMetaType::Int, 0x00495001,
      39, QMetaType::Int, 0x00495001,
      40, 0x80000000 | 35, 0x00495009,
      41, QMetaType::Int, 0x00495001,
      42, QMetaType::Int, 0x00495001,
      43, QMetaType::Int, 0x00495001,
      44, QMetaType::Int, 0x00495001,
      45, 0x80000000 | 6, 0x00495009,
      46, QMetaType::QRect, 0x00495001,
      47, QMetaType::Bool, 0x00495001,

 // properties: notify_signal_id
       1,
       1,
       1,
       1,
       1,
       2,
       2,
       2,
       2,
       2,
       3,
       4,
       5,

       0        // eod
};

void KDecoration2::Decoration::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Decoration *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->blurRegionChanged(); break;
        case 1: _t->bordersChanged(); break;
        case 2: _t->resizeOnlyBordersChanged(); break;
        case 3: _t->sectionUnderMouseChanged((*reinterpret_cast< Qt::WindowFrameSection(*)>(_a[1]))); break;
        case 4: _t->titleBarChanged(); break;
        case 5: _t->opaqueChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->shadowChanged((*reinterpret_cast< const QSharedPointer<DecorationShadow>(*)>(_a[1]))); break;
        case 7: _t->damaged((*reinterpret_cast< const QRegion(*)>(_a[1]))); break;
        case 8: _t->requestClose(); break;
        case 9: _t->requestToggleMaximization((*reinterpret_cast< Qt::MouseButtons(*)>(_a[1]))); break;
        case 10: _t->requestMinimize(); break;
        case 11: _t->requestContextHelp(); break;
        case 12: _t->requestToggleOnAllDesktops(); break;
        case 13: _t->requestToggleShade(); break;
        case 14: _t->requestToggleKeepAbove(); break;
        case 15: _t->requestToggleKeepBelow(); break;
        case 16: _t->requestShowWindowMenu(); break;
        case 17: _t->requestShowWindowMenu((*reinterpret_cast< const QRect(*)>(_a[1]))); break;
        case 18: _t->requestShowToolTip((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 19: _t->requestHideToolTip(); break;
        case 20: _t->showApplicationMenu((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 21: _t->requestShowApplicationMenu((*reinterpret_cast< const QRect(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 22: _t->update((*reinterpret_cast< const QRect(*)>(_a[1]))); break;
        case 23: _t->update(); break;
        case 24: _t->init(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QSharedPointer<DecorationShadow> >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (Decoration::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Decoration::blurRegionChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (Decoration::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Decoration::bordersChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (Decoration::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Decoration::resizeOnlyBordersChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (Decoration::*)(Qt::WindowFrameSection );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Decoration::sectionUnderMouseChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (Decoration::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Decoration::titleBarChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (Decoration::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Decoration::opaqueChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (Decoration::*)(const QSharedPointer<DecorationShadow> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Decoration::shadowChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (Decoration::*)(const QRegion & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Decoration::damaged)) {
                *result = 7;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<Decoration *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QMargins*>(_v) = _t->borders(); break;
        case 1: *reinterpret_cast< int*>(_v) = _t->borderLeft(); break;
        case 2: *reinterpret_cast< int*>(_v) = _t->borderRight(); break;
        case 3: *reinterpret_cast< int*>(_v) = _t->borderTop(); break;
        case 4: *reinterpret_cast< int*>(_v) = _t->borderBottom(); break;
        case 5: *reinterpret_cast< QMargins*>(_v) = _t->resizeOnlyBorders(); break;
        case 6: *reinterpret_cast< int*>(_v) = _t->resizeOnlyBorderLeft(); break;
        case 7: *reinterpret_cast< int*>(_v) = _t->resizeOnlyBorderRight(); break;
        case 8: *reinterpret_cast< int*>(_v) = _t->resizeOnlyBorderTop(); break;
        case 9: *reinterpret_cast< int*>(_v) = _t->resizeOnlyBorderBottom(); break;
        case 10: *reinterpret_cast< Qt::WindowFrameSection*>(_v) = _t->sectionUnderMouse(); break;
        case 11: *reinterpret_cast< QRect*>(_v) = _t->titleBar(); break;
        case 12: *reinterpret_cast< bool*>(_v) = _t->isOpaque(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject KDecoration2::Decoration::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_KDecoration2__Decoration.data,
    qt_meta_data_KDecoration2__Decoration,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KDecoration2::Decoration::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDecoration2::Decoration::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KDecoration2__Decoration.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KDecoration2::Decoration::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 13;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 13;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 13;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 13;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 13;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KDecoration2::Decoration::blurRegionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KDecoration2::Decoration::bordersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KDecoration2::Decoration::resizeOnlyBordersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KDecoration2::Decoration::sectionUnderMouseChanged(Qt::WindowFrameSection _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KDecoration2::Decoration::titleBarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KDecoration2::Decoration::opaqueChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void KDecoration2::Decoration::shadowChanged(const QSharedPointer<DecorationShadow> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void KDecoration2::Decoration::damaged(const QRegion & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
